Introduction
============

The MuonDataLib package is an open source library for handling MuSR data.
The package is cross platform, supporting Windows, Mac OS and Linux.
This package has been developed by Anthony Lim from STFC’s ISIS Neutron and Muon facility.

